nbxmpp.simplexml.T

Package nbxmpp :: Module simplexml :: Class T |
[hide private]
[frames] | no frames]

# Class T

source code

Auxiliary class used to quick access to node's child nodes

Instance Methods | [hide private]
__init__(self, node) | source code
__getattr__(self, attr) | source code
__setattr__(self, attr, val) | source code
__delattr__(self, attr) | source code

Method Details | [hide private]

### __init__(self, node) (Constructor) | source code

### __getattr__(self, attr) (Qualification operator) | source code

### __setattr__(self, attr, val) | source code

### __delattr__(self, attr) | source code